@@ -1,5 +1,4 @@
 
-from framl.config_cli import ConfigFraml
 import json
 import os
 import time
@@ -17,7 +16,7 @@ class FeatureStore:
         self._get_token()
 
     def _get_token(self):
-        if time.time() > self.token_exp - 10:
+        if time.time()+10 > self.token_exp:
             token = FeatureStore._fetch_token()
             self.token = token["bearer"]
             self.token_exp = token["expiration"]
@@ -25,8 +24,7 @@ class FeatureStore:
 
     @staticmethod
     def _fetch_token() -> dict:
-        env = ConfigFraml.get_env()
-        if env.lower() != "production":
+        if os.environ.get('FRAML_ENV') != "production":
             warnings.warn("using local identity token")
             result = subprocess.run(["gcloud", "auth", "print-identity-token"], stdout=subprocess.PIPE)
             bearer = result.stdout.decode('utf-8').replace("\n", "")
@@ -40,8 +38,7 @@ class FeatureStore:
             # Fetch the token
             token_response = requests.get(token_request_url, headers=token_request_headers)
             bearer = token_response.content.decode("utf-8")
-            print(bearer)
-            exp = jwt.decode(bearer)['exp']
+            exp = jwt.decode(bearer, algorithms='RS256', verify=False)['exp']
 
         return {"bearer": bearer, "expiration": exp}
 
@@ -49,7 +46,7 @@ class FeatureStore:
         # Provide the token in the request to the receiving service
         receiving_service_headers = {
             'Authorization': f'bearer {self._get_token()}',
-            'Content-type':  'application/json; charset=utf-8'
+            'Content-type':  'application/json; charset=utf-8',
         }
 
         # sending the request. Please make sure the payload is a valid json string
@@ -65,7 +62,7 @@ class FeatureStore:
         # Provide the token in the request to the receiving service
         receiving_service_headers = {
             'Authorization': f'bearer {self._get_token()}',
-            'Content-type':  'application/json; charset=utf-8'
+            'Content-type':  'application/json; charset=utf-8',
         }
 
         # sending the request. Please make sure the payload is a valid json string
